@@ -80,9 +80,11 @@ __MERCHANT_CUSTOMER_REWARD_SCHEMA = {
                             bigquery.SchemaField('TransactDateTime', 'DATETIME'),
                             bigquery.SchemaField('RewardFormat', 'STRING'),
                             bigquery.SchemaField('RewardAmount', 'FLOAT64'),
-                            bigquery.SchemaField('ExpiryDate', 'DATETIME'),
+                            bigquery.SchemaField('ExpiryDate', 'DATE'),
                             bigquery.SchemaField('RewardFormatKey', 'STRING'),
                             bigquery.SchemaField('RewardedDateTime', 'DATETIME'),
+                            bigquery.SchemaField('Reverted', 'BOOLEAN'),
+                            bigquery.SchemaField('RevertedDateTime', 'DATETIME'),
                             bigquery.SchemaField('UpdatedDateTime', 'DATETIME'),
                             }
 
